ACSTOOLS
========

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.3728240.svg
   :alt: zenodo.3728240
   :target: https://doi.org/10.5281/zenodo.3728240

.. image:: https://readthedocs.org/projects/acstools/badge/?version=latest
    :alt: Documentation Status
    :target: https://acstools.readthedocs.io/en/latest/?badge=latest

.. image:: https://dev.azure.com/spacetelescope/acstools/_apis/build/status/spacetelescope.acstools?branchName=master
    :alt: Azure CI Status
    :target: https://dev.azure.com/spacetelescope/acstools/_build/latest?definitionId=12&branchName=master

.. image:: https://ssbjenkins.stsci.edu/job/STScI/job/acstools/job/master/badge/icon
    :alt: Jenkins CI Status
    :target: https://ssbjenkins.stsci.edu/job/STScI/job/acstools/job/master/

Nightly regression test results are available only from within the STScI
network at this time.
https://plwishmaster.stsci.edu:8081/job/RT/job/acstools/test_results_analyzer/
